documentationtools.FunctionCrawler
==================================

.. abjad-lineage:: abjad.tools.documentationtools.FunctionCrawler.FunctionCrawler

.. autoclass:: abjad.tools.documentationtools.FunctionCrawler.FunctionCrawler

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.documentationtools.FunctionCrawler.FunctionCrawler.code_root
      ~abjad.tools.documentationtools.FunctionCrawler.FunctionCrawler.include_private_objects
      ~abjad.tools.documentationtools.FunctionCrawler.FunctionCrawler.module_crawler
      ~abjad.tools.documentationtools.FunctionCrawler.FunctionCrawler.root_package_name
      ~abjad.tools.documentationtools.FunctionCrawler.FunctionCrawler.__call__
      ~abjad.tools.documentationtools.FunctionCrawler.FunctionCrawler.__eq__
      ~abjad.tools.documentationtools.FunctionCrawler.FunctionCrawler.__format__
      ~abjad.tools.documentationtools.FunctionCrawler.FunctionCrawler.__ne__
      ~abjad.tools.documentationtools.FunctionCrawler.FunctionCrawler.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.documentationtools.FunctionCrawler.FunctionCrawler.code_root
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.FunctionCrawler.FunctionCrawler.include_private_objects
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.FunctionCrawler.FunctionCrawler.module_crawler
   :noindex:

.. autoattribute:: abjad.tools.documentationtools.FunctionCrawler.FunctionCrawler.root_package_name
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.documentationtools.FunctionCrawler.FunctionCrawler.__call__
   :noindex:

.. automethod:: abjad.tools.documentationtools.FunctionCrawler.FunctionCrawler.__eq__
   :noindex:

.. automethod:: abjad.tools.documentationtools.FunctionCrawler.FunctionCrawler.__format__
   :noindex:

.. automethod:: abjad.tools.documentationtools.FunctionCrawler.FunctionCrawler.__ne__
   :noindex:

.. automethod:: abjad.tools.documentationtools.FunctionCrawler.FunctionCrawler.__repr__
   :noindex:
